# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: system.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csystem.proto\x12\x14shiftcrypto.bitbox02\"s\n\rRebootRequest\x12<\n\x07purpose\x18\x01 \x01(\x0e\x32+.shiftcrypto.bitbox02.RebootRequest.Purpose\"$\n\x07Purpose\x12\x0b\n\x07UPGRADE\x10\x00\x12\x0c\n\x08SETTINGS\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'system_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REBOOTREQUEST._serialized_start=38
  _REBOOTREQUEST._serialized_end=153
  _REBOOTREQUEST_PURPOSE._serialized_start=117
  _REBOOTREQUEST_PURPOSE._serialized_end=153
# @@protoc_insertion_point(module_scope)
