"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RebootRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Purpose:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _PurposeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RebootRequest._Purpose.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UPGRADE: RebootRequest._Purpose.ValueType  # 0
        SETTINGS: RebootRequest._Purpose.ValueType  # 1
    class Purpose(_Purpose, metaclass=_PurposeEnumTypeWrapper):
        pass

    UPGRADE: RebootRequest.Purpose.ValueType  # 0
    SETTINGS: RebootRequest.Purpose.ValueType  # 1

    PURPOSE_FIELD_NUMBER: builtins.int
    purpose: global___RebootRequest.Purpose.ValueType
    def __init__(self,
        *,
        purpose: global___RebootRequest.Purpose.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["purpose",b"purpose"]) -> None: ...
global___RebootRequest = RebootRequest
